@@ -13,8 +13,8 @@
 #    under the License.
 
 import json
+from unittest import mock
 
-import mock
 import testtools
 
 from proliantutils.redfish.resources.system.storage import array_controller
@@ -34,7 +34,8 @@ class HPEArrayControllerTestCase(testtools.TestCase):
 
         path = ("/redfish/v1/Systems/1/SmartStorage/ArrayControllers")
         self.sys_stor = array_controller.HPEArrayController(
-            self.conn, path, '1.0.2', None)
+            self.conn, path, redfish_version='1.0.2',
+            registries=None, root=None)
 
     def test__parse_attributes(self):
         self.sys_stor._parse_attributes(self.json_doc)
@@ -91,7 +92,7 @@ class HPEArrayControllerCollectionTestCase(testtools.TestCase):
         self.conn.get.return_value.json.return_value = self.json_doc
         self.sys_stor_col = array_controller.HPEArrayControllerCollection(
             self.conn, '/redfish/v1/Systems/1/SmartStorage/ArrayControllers',
-            '1.0.2', None)
+            redfish_version='1.0.2', registries=None, root=None)
 
     def test__parse_attributes(self):
         self.sys_stor_col._parse_attributes(self.json_doc)
@@ -108,7 +109,8 @@ class HPEArrayControllerCollectionTestCase(testtools.TestCase):
         mock_eth.assert_called_once_with(
             self.sys_stor_col._conn,
             '/redfish/v1/Systems/1/SmartStorage/ArrayControllers/0',
-            self.sys_stor_col.redfish_version, None)
+            redfish_version=self.sys_stor_col.redfish_version,
+            registries=None, root=self.sys_stor_col.root)
 
     @mock.patch.object(array_controller, 'HPEArrayController', autospec=True)
     def test_get_members(self, mock_eth):
@@ -116,7 +118,8 @@ class HPEArrayControllerCollectionTestCase(testtools.TestCase):
         path = ("/redfish/v1/Systems/1/SmartStorage/ArrayControllers/0")
         calls = [
             mock.call(self.sys_stor_col._conn, path,
-                      self.sys_stor_col.redfish_version, None),
+                      redfish_version=self.sys_stor_col.redfish_version,
+                      registries=None, root=self.sys_stor_col.root),
         ]
         mock_eth.assert_has_calls(calls)
         self.assertIsInstance(members, list)
