@@ -13,8 +13,8 @@
 #    under the License.
 
 import json
+from unittest import mock
 
-import mock
 import testtools
 
 from proliantutils.redfish.resources.system.storage import array_controller
@@ -34,7 +34,7 @@ class HPESmartStorageTestCase(testtools.TestCase):
 
         path = ("/redfish/v1/Systems/1/SmartStorage")
         self.sys_stor = smart_storage.HPESmartStorage(
-            self.conn, path, '1.0.2', None)
+            self.conn, path, '1.0.2', registries=None, root=None)
 
     def test__parse_attributes(self):
         self.sys_stor._parse_attributes(self.json_doc)
