@@ -1,4 +1,4 @@
-# Copyright 2017 Hewlett Packard Enterprise Development LP
+# Copyright 2017-2022 Hewlett Packard Enterprise Development LP
 # All Rights Reserved.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -14,8 +14,8 @@
 #    under the License.
 
 import json
+from unittest import mock
 
-import mock
 import testtools
 
 from proliantutils.redfish.resources.system import pci_device
@@ -33,7 +33,8 @@ class PCIDeviceTestCase(testtools.TestCase):
 
         pci_path = "/redfish/v1/Systems/1/PCIDevices/1"
         self.sys_pci = pci_device.PCIDevice(
-            self.conn, pci_path, '1.0.2', None)
+            self.conn, pci_path, redfish_version='1.0.2',
+            registries=None, root=None)
 
     def test__parse_attributes(self):
         self.sys_pci._parse_attributes(self.json_doc)
@@ -53,7 +54,7 @@ class PCIDeviceCollectionTestCase(testtools.TestCase):
         self.conn.get.return_value.json.return_value = self.json_doc
         self.sys_pci_col = pci_device.PCIDeviceCollection(
             self.conn, '/redfish/v1/Systems/1/PCIDevices',
-            redfish_version='1.0.2')
+            redfish_version='1.0.2', registries=None, root=None)
 
     def test__parse_attributes(self):
         self.sys_pci_col._parse_attributes(self.json_doc)
@@ -70,7 +71,8 @@ class PCIDeviceCollectionTestCase(testtools.TestCase):
         mock_pci.assert_called_once_with(
             self.sys_pci_col._conn,
             ('/redfish/v1/Systems/1/PCIDevices/1'),
-            self.sys_pci_col.redfish_version, None)
+            redfish_version=self.sys_pci_col.redfish_version,
+            registries=None, root=self.sys_pci_col.root)
 
     @mock.patch.object(pci_device, 'PCIDevice', autospec=True)
     def test_get_members(self, mock_pci):
@@ -79,9 +81,11 @@ class PCIDeviceCollectionTestCase(testtools.TestCase):
                      "/redfish/v1/Systems/1/PCIDevices/6"]
         calls = [
             mock.call(self.sys_pci_col._conn, path_list[0],
-                      self.sys_pci_col.redfish_version, None),
+                      redfish_version=self.sys_pci_col.redfish_version,
+                      registries=None, root=self.sys_pci_col.root),
             mock.call(self.sys_pci_col._conn, path_list[1],
-                      self.sys_pci_col.redfish_version, None)
+                      redfish_version=self.sys_pci_col.redfish_version,
+                      registries=None, root=self.sys_pci_col.root)
         ]
         mock_pci.assert_has_calls(calls)
         self.assertIsInstance(members, list)
@@ -99,7 +103,10 @@ class PCIDeviceCollectionTestCase(testtools.TestCase):
         with open(path, 'r') as f:
             val.append(json.loads(f.read()))
         self.conn.get.return_value.json.side_effect = val
-        self.assertEqual(1, len(self.sys_pci_col.gpu_devices))
+        expected = ["/redfish/v1/Systems/1/PCIDevices/6/"]
+        actual = self.sys_pci_col.gpu_devices
+        self.assertEqual(1, len(actual))
+        self.assertEqual(expected, actual)
 
     def test_max_nic_capacity(self):
         self.conn.get.return_value.json.reset_mock()
@@ -112,7 +119,27 @@ class PCIDeviceCollectionTestCase(testtools.TestCase):
                 'pci_device1.json')
         with open(path, 'r') as f:
             val.append(json.loads(f.read()))
+        path = ('proliantutils/tests/redfish/json_samples/'
+                'pci_device2.json')
+        with open(path, 'r') as f:
+            val.append(json.loads(f.read()))
         self.conn.get.return_value.json.side_effect = val
         actual_capacity = self.sys_pci_col.max_nic_capacity
         expected = '1Gb'
         self.assertEqual(expected, actual_capacity)
+
+    def test_vendor_id(self):
+        self.conn.get.return_value.json.reset_mock()
+        val = []
+        path = ('proliantutils/tests/redfish/json_samples/'
+                'pci_device.json')
+        with open(path, 'r') as f:
+            val.append(json.loads(f.read()))
+        path = ('proliantutils/tests/redfish/json_samples/'
+                'pci_device1.json')
+        with open(path, 'r') as f:
+            val.append(json.loads(f.read()))
+        self.conn.get.return_value.json.side_effect = val
+        expected_vendor_id = {'6': 4139}
+        self.assertEqual(expected_vendor_id,
+                         self.sys_pci_col.vendor_id)
